=============
CellarTracker
=============


.. image:: https://img.shields.io/pypi/v/cellartracker.svg
        :target: https://pypi.python.org/pypi/cellartracker

.. image:: https://travis-ci.com/mathroule/cellartracker.svg?branch=master
        :target: https://travis-ci.com/mathroule/cellartracker

.. image:: https://readthedocs.org/projects/cellartracker/badge/?version=latest
        :target: https://cellartracker.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/mathroule/cellartracker/shield.svg
     :target: https://pyup.io/repos/github/mathroule/cellartracker/
     :alt: Updates



Python package to export CellarTracker data.


* Free software: MIT license
* Documentation: https://cellartracker.readthedocs.io.


Features
--------

Use the `CellarTracker export data`_ capabilities.

.. _CellarTracker export data: https://support.cellartracker.com/article/29-exporting-data


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
